/*
 * RetryHandler.java
 *
 * Copyright (C) 2022 by RStudio, PBC
 *
 * Unless you have received this program directly from RStudio pursuant
 * to the terms of a commercial license agreement with RStudio, then
 * this program is licensed to you under the terms of version 3 of the
 * GNU Affero General Public License. This program is distributed WITHOUT
 * ANY EXPRESS OR IMPLIED WARRANTY, INCLUDING THOSE OF NON-INFRINGEMENT,
 * MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE. Please refer to the
 * AGPL (http://www.gnu.org/licenses/agpl-3.0.txt) for more details.
 *
 */
package org.rstudio.studio.client.server.remote;

import org.rstudio.core.client.jsonrpc.RpcError;
import org.rstudio.core.client.jsonrpc.RpcRequest;

interface RetryHandler
{
   // perform the retry 
   void onRetry();

   // retry the operation with a modified request
   void onModifiedRetry(RpcRequest modifiedRequest);
   
   // will be called with the original error that caused the retry attempt
   // if there is an error involving the retry mechanism itself (e.g. error
   // occurs during attempt to authenticate in response to UNAUTHORIZED)
   void onError(RpcError error);
}
